@@ -78,10 +78,25 @@ class GetParamLocaleMiddleware(object):
     """
     This Middleware sets the language from a GET param.
     """
-    def process_request(self, request):
+
+    def get_lang_param(self, request):
         if request.method == 'GET' and request.GET.get('lang'):
             language = request.GET['lang']
             for lang in settings.LANGUAGES:
                 if lang[0] == language:
-                    translation.activate(language)
-                    request.LANGUAGE_CODE = translation.get_language()
+                    return language
+        return None
+
+    def process_request(self, request):
+        language = self.get_lang_param(request)
+        if language:
+            translation.activate(language)
+            request.LANGUAGE_CODE = translation.get_language()
+
+    def process_response(self, request, response):
+        language = self.get_lang_param(request)
+        if language:
+            response.set_cookie(settings.LANGUAGE_COOKIE_NAME, language)
+        return response
+
+
